@@ -1,5 +1,5 @@
 def task_version():
-	return {'actions': ['bzr version-info --custom --template="{revno}\n"']}
+	return {'actions': ['bzr revno']}
 
 def task_send_email():
 	return {'actions': ['echo "TODO: send an email"'],
