@@ -5,11 +5,11 @@ import sys
 import traceback
 
 import doit
-from doit.exceptions import InvalidDodoFile, InvalidCommand, InvalidTask
-from doit import loader
-from doit import cmdparse
-from doit.cmds import doit_run, doit_clean, doit_list, doit_forget, doit_ignore
-from doit.cmds import doit_auto
+from .exceptions import InvalidDodoFile, InvalidCommand, InvalidTask
+from . import loader
+from . import cmdparse
+from .cmds import doit_run, doit_clean, doit_list, doit_forget, doit_ignore
+from .cmds import doit_auto
 
 ## cmd line options
 ##########################################################
@@ -51,7 +51,7 @@ opt_cwd = {'name': 'cwdPath',
                    "dodo file are relative to dodo.py location.")
            }
 
-# continue executing tasks even after a failure
+# seek dodo file on parent folders
 opt_seek_file = {'name': 'seek_file',
                  'short': '',
                  'long': 'seek-file',
@@ -74,7 +74,7 @@ opt_outfile = {'name': 'outfile',
 # choose internal dependency file.
 opt_depfile = {'name': 'dep_file',
                'short':'',
-               'long': '',
+               'long': 'db-file',
                'type': str,
                'default': ".doit.db",
                'help': "file used to save successful runs"
@@ -94,6 +94,7 @@ opt_always = {'name': 'always',
 opt_continue = {'name': 'continue',
                 'short': 'c',
                 'long': 'continue',
+                'inverse': 'no-continue',
                 'type': bool,
                 'default': False,
                 'help': "continue executing tasks even after a failure "
@@ -449,8 +450,8 @@ def cmd_main(cmd_args):
     sub_cmd['help'] = cmdparse.Command('help', (), cmd_help, help_doc)
 
     # run command
-    run_options = (opt_version, opt_help, opt_dodo, opt_cwd, opt_seek_file,
-                   opt_depfile, opt_always, opt_continue, opt_verbosity,
+    run_options = (opt_version, opt_help, opt_dodo, opt_cwd, opt_depfile,
+                   opt_seek_file, opt_always, opt_continue, opt_verbosity,
                    opt_reporter, opt_outfile, opt_num_process)
     sub_cmd['run'] = cmdparse.Command('run', run_options, cmd_run, run_doc)
 
