@@ -40,7 +40,8 @@ class TestCmdAction(object):
     # if nothing is raised it is successful
     def test_success(self):
         my_action = action.CmdAction(PROGRAM)
-        my_action.execute()
+        got = my_action.execute()
+        assert got is None
 
     def test_error(self):
         my_action = action.CmdAction("%s 1 2 3" % PROGRAM)
@@ -464,6 +465,7 @@ class TestCreateAction(object):
         class Sample(action.BaseAction): pass
         my_action = action.create_action(Sample(), self.mytask)
         assert isinstance(my_action, Sample)
+        assert self.mytask == my_action.task
 
     def testStringAction(self):
         my_action = action.create_action("xpto 14 7", self.mytask)
