@@ -141,6 +141,10 @@ class TestRunner_SelectTask(object):
         t2 = Task('t2', [(check_x,)], getargs={'my_x':'t1.x'})
         my_runner = runner.Runner(depfile.name, reporter)
 
+        # t2 gives chance for setup tasks to be executed
+        assert False == my_runner.select_task(t2)
+        assert ('start', t2) == reporter.log.pop(0)
+
         # execute task t1 to calculate value
         assert True == my_runner.select_task(t1)
         assert ('start', t1) == reporter.log.pop(0)
@@ -152,7 +156,6 @@ class TestRunner_SelectTask(object):
         # t2.options are set on select_task
         assert {} == t2.options
         assert True == my_runner.select_task(t2)
-        assert ('start', t2) == reporter.log.pop(0)
         assert not reporter.log
         assert {'my_x': 1} == t2.options
 
@@ -163,6 +166,10 @@ class TestRunner_SelectTask(object):
         t2 = Task('t2', [(check_x,)], getargs={'my_x':'t1.x'})
         my_runner = runner.Runner(depfile.name, reporter)
 
+        # t2 gives chance for setup tasks to be executed
+        assert False == my_runner.select_task(t2)
+        assert ('start', t2) == reporter.log.pop(0)
+
         # execute task t1 to calculate value
         assert True == my_runner.select_task(t1)
         assert ('start', t1) == reporter.log.pop(0)
@@ -173,7 +180,6 @@ class TestRunner_SelectTask(object):
 
         # select_task t2 fails
         assert False == my_runner.select_task(t2)
-        assert ('start', t2) == reporter.log.pop(0)
         assert ('fail', t2) == reporter.log.pop(0)
         assert not reporter.log
 
@@ -191,6 +197,17 @@ class TestTask_Teardown(object):
         assert ('teardown', t1) == reporter.log.pop(0)
         assert not reporter.log
 
+    def test_reverse_order(self, reporter, depfile):
+        def do_nothing():pass
+        t1 = Task('t1', [], teardown=[do_nothing])
+        t2 = Task('t2', [], teardown=[do_nothing])
+        my_runner = runner.Runner(depfile.name, reporter)
+        my_runner.teardown_list = [t1, t2]
+        my_runner.teardown()
+        assert ('teardown', t2) == reporter.log.pop(0)
+        assert ('teardown', t1) == reporter.log.pop(0)
+        assert not reporter.log
+
     def test_errors(self, reporter, depfile):
         def raise_something(x):
             raise Exception(x)
@@ -199,10 +216,10 @@ class TestTask_Teardown(object):
         my_runner = runner.Runner(depfile.name, reporter)
         my_runner.teardown_list = [t1, t2]
         my_runner.teardown()
-        assert ('teardown', t1) == reporter.log.pop(0)
-        assert ('cleanup_error',) == reporter.log.pop(0)
         assert ('teardown', t2) == reporter.log.pop(0)
         assert ('cleanup_error',) == reporter.log.pop(0)
+        assert ('teardown', t1) == reporter.log.pop(0)
+        assert ('cleanup_error',) == reporter.log.pop(0)
         assert not reporter.log
 
 
@@ -337,17 +354,6 @@ class TestRunner_run_tasks(object):
         d = Dependency(depfile.name)
         assert d._get("taskX", os.path.abspath(depPath))
 
-    # when successful and run_once is updated
-    def test_successRunOnce(self, reporter, RunnerClass, depfile):
-        tasks = [Task("taskX", [my_print], run_once=True)]
-        my_runner = RunnerClass(depfile.name, reporter)
-        tc = TaskControl(tasks)
-        tc.process(None)
-        my_runner.run_tasks(tc)
-        assert runner.SUCCESS == my_runner.finish()
-        d = Dependency(depfile.name)
-        assert True == d.get_values('taskX').get('run-once')
-
     def test_resultDependency(self, reporter, RunnerClass, depfile):
         t1 = Task("t1", [(ok,)])
         t2 = Task("t2", [(ok,)], result_dep=['t1'])
@@ -424,10 +430,10 @@ class TestRunner_run_tasks(object):
         tc.process(None)
         my_runner.run_tasks(tc)
         assert runner.SUCCESS == my_runner.finish()
+        assert ('start', tasks[0]) == reporter.log.pop(0)
         assert ('start', tasks[1]) == reporter.log.pop(0)
         assert ('execute', tasks[1]) == reporter.log.pop(0)
         assert ('success', tasks[1]) == reporter.log.pop(0)
-        assert ('start', tasks[0]) == reporter.log.pop(0)
         assert ('execute', tasks[0]) == reporter.log.pop(0)
         assert ('success', tasks[0]) == reporter.log.pop(0)
         assert 0 == len(reporter.log)
